/*
  e-Gizmo Voice Control Command Module (VCCM)

  This code defines a function that takes two outputs -
  one decimal and one string equivalent to the command.
  It then prints/display outputs. The dynamicDecimalCode
  and the *myStrings[] are just sample values to show how
  the function works. This is a customized commands and it is
  built in in e-Gizmo VCCM module. You can select one of these
  firmware to use.

  Required Firmwares: egizmo1v72 (no reply word) or
                      egizmo1v73 (with reply word)

  Visit our page: https://www.e-gizmo.net
  Manual Guide: https://e-gizmo.net/oc/kits%20documents/Voice%20Control%20Command%20Module%20%28e-GizmoVCCM%29/e-Gizmo%20VCCM.pdf
  Product Page: https://www.e-gizmo.net/gizmoshop/index.php?route=product/product&search=voice+con&product_id=1633
  


*/

#include "eGizmoVoiceCommand.h"
#include <SoftwareSerial.h>


/// Serial Communication (RX,TX)
SoftwareSerial eGizmoSerial(10, 11);

char *myStrings[] = {
  //wake-uo reply
  "I am here|Please go ahead|What can I do for you?",
  //reply for quit
  //{"Pleas call me if necessary", 0x1},
  //Table A. Robot commands
  "Ok, Grip Engage", //1
  "Ok, Grip Release", //2
  "Ok, Start Position", //3
  "Ok, Standby", //4
  "Ok, Faster", //5
  "Ok, Grip Slower", //6
  "Ok, Grip Stop", //7
  //Table B. Servo Actuator Commands (Used ad preample combined with Table C command set)
  "Ok, Group Arm", //8
  "Ok, Group Servo One ", //9
  "Ok, Group Servo Two", //10
  "Ok, Group Servo Three", //11
  "Ok, Group Servo Four ", //12
  "Ok, Servo Cancel", //13
  //Table C. Stored Servo/Positioning (These set of command follows aftr Table B)
  "Ok, Goto Home", //14
  "Ok, Goto One", //15
  "Ok, Goto Two", //16
  "Ok, Goto Three", //17
  "Ok, Goto Four", //18
  "Ok, Goto Five", //19
  "Ok, Goto Six", //20
  "Ok, Goto Seven", //21
  "Ok, Goto Eight", //22
  "Ok, Goto Nine", //23
  "Ok, Goto Ten", //24
  "Ok, Goto Eleven", //25
  "Ok, Goto Twelve", //26
  "Ok, Goto Thirteen", //27
  "Ok, Goto Fourteen", //28
  "Ok, Goto Fifteen", //29
  "Ok, Goto Next", //30
  "Ok, Goto Previous", //31
  //Table D. Stored Gait/Sequence
  "Ok, Move Gait One", //32
  "Ok, Move Gait Two", //33
  "Ok, Move Gait Three", //34
  "Ok, Move Gait Four", //35
  "Ok, Move Gait Five", //36
  "Ok, Move Gait Six", //37
  "Ok, Move Gait Seven", //38
  "Ok, Move Gait Eight", //39
  "Ok, Move Gait Nine", //40
  "Ok, Move Gait Ten", //41
  "Ok, Move Gait Eleven", //42
  "Ok, Move Gait Twelve", //43
  "Ok, Move Gait Thirteen", //44
  "Ok, Move Gait Fourteen", //45
  "Ok, Move Gait Fifteen", //46
  "Ok, Move Next", //47
  "Ok, Move Previous", //48
  //Table F. Home Devices
  "Ok, Switch On", //49
  "Ok, Switch Off", //50
  "Ok, Switch Low", //51
  "Ok, Switch Medium", //52
  "Ok, Switch High", //53
  "Ok, Emergency on", //54
  "Ok, Emergency off", //55
  "Ok, Red light on", //56
  "Ok, Red light off", //57
  "Ok, Green light on", //58
  "Ok, Green light off", //59
  "Ok, Blue light on", //60
  "Ok, Blue light off", //61
  "Ok, Lights on", //62
  "Ok, Lights off", //63
  "Ok, Lights One on", //64
  "Ok, Lights One off", //65
  "Ok, Lights Two on", //66
  "Ok, Lights Two off", //67
  "Ok, Lights Three on", //68
  "Ok, Lights Three off", //69

  "Ok, Lights Four on", //70
  "Ok, Lights Four off", //71
  "Ok, Turn on the fan", //72
  "Ok, Turn off the fan", //73
  "Ok, Fan one turn on", //74
  "Ok, Fan one turn off", //75
  "Ok, Fan two turn on", //76
  "Ok, Fan two turn off", //77
  "Ok, Fan three turn on", //78
  "Ok, Fan three turn off", //79
  "Ok, Motor on", //80
  "Ok, Motor off", //81
  "Ok, Motor One on", //82
  "Ok, Motor One off", //83
  "Ok, Motor Two on", //84
  "Ok, Motor Two off", //85

  "Ok, Pump On", //86
  "Ok, Pump Off", //87
  "Ok, Pump One On", //88
  "Ok, Pump One off", //89
  "Ok, Pump Two On", //90
  "Ok, Pump Two Off", //91
  "Ok, Turn on the washing", //92
  "Ok, Turn off the washing", //93
  "Ok, Turn on the aircon", //94
  "Ok, Turn off the aircon", //95
  "Ok, Turn on the radio", //96
  "Ok, Turn off the radio", //97
  "Ok, Turn on the stereo", //98
  "Ok, Turn off the stereo", //99
  "Ok, Open the garage", //100
  "Ok, CLose the garage", //101

  "Ok, Open the gate", //102
  "Ok, Close the gate", //103
  "Ok, Open the door", //104
  "Ok, Close the door", //105
  "Ok, Turn on the TV", //106
  "Ok, Turn off the TV", //107
  "Ok, Turn on the computer", //108
  "Ok, Turn off the computer", //109
  "Ok, Turn on the laptop", //110
  "Ok, Turn off the laptop", //111
  "Ok, Turn on the monitor", //112
  "Ok, Turn off the monitor", //113
  "Ok, Turn on the videoke", //114
  "Ok, Turn off the videoke", //115
  "Ok, Turn on the extension", //116
  "Ok, Turn off the extension", //117

  "Ok, Living room lights on", //118
  "Ok, Living room lights off", //119
  "Ok, Master room ligts on", //120
  "Ok, Master room ligts off", //121
  "Ok, Guest room lights on", //122
  "Ok, Guest room lights off", //123
  "Ok, Bedroom A lights on", //124
  "Ok, Bedroom A lights off", //125
  "Ok, Bedroom B lights on", //126
  "Ok, Bedroom B lights off", //127
  "Ok, Bedroom C lights on", //128
  "Ok, Bedroom C lights off", //129
  "Ok, Maid room lights on", //130
  "Ok, Maid room lights off", //131
  "Ok, Pantry lights on", //132
  "Ok, Pantry lights off", //133

  "Ok, Dining lights on", //134
  "Ok, Dining lights off", //135
  "Ok, Patio lights on", //136
  "Ok, Patio lights off", //137
  "Ok, Pool lights on", //138
  "Ok, Pool lights off", //139
  //Motor Commands
  "Ok, Forward", //140
  "Ok, Reverse", //141
  "Ok, Turn Right", //142
  "Ok, Turn Left" //143
  "Ok, Move Around", //144
  "Ok, Halt", //145
  "Ok, Soft Left", //146
  "Ok, Soft Right ", //147
  "Ok, Spin Left", //148
  "Ok, Spin Right", //149
  "Ok, Run Forward" //150

  /*You can modify the string command reply here*/
  /*Note: That the last string has no comma (,)*/
};

void setup() {
  Serial.begin(115200);
  while (!Serial); // wait for serial port to connect. Needed for native USB port only , This port is for displaying data that sends.

  eGizmoSerial.begin(115200); // Make sure to set the baud rate to match your communication
  Serial.println("waiting for the commands...");
}
int i;
void loop() {
  // Your main code here
  uint8_t *voiceData = detecteGizmoVoiceSensor(&eGizmoSerial);

  if (voiceData != NULL) {
    uint8_t dynamicHDecimalCode = voiceData[1];

    Serial.print(myStrings[dynamicHDecimalCode]);
    Serial.print(", DEC: ");
    Serial.println(dynamicHDecimalCode);
  }
  delay(1000);
}